zms.zmscontainerobject.ZMSContainerObject

Package zms :: Module zmscontainerobject :: Class ZMSContainerObject |
[frames] | no frames]

# Class ZMSContainerObject

                                                                                                                                                                                                      zms.zmsobject.ZMSObject --+
                                                                                                                                                                                                                                |
    ExtensionClass("Base", (object,), {'__slots__':(), '__getattribute__': Base_getattro, '__getstate__': Base__getstate__, '__setstate__': Base__setstate__, '__reduce__': Base__reduce__, '__new__': Base__new__,}) --+       |
                                                                                                                                                                                                                        |       |
                                                                                                                                                                          AccessControl.PermissionMapping.RoleManager --+       |
                                                                                                                                                                                                                        |       |
                                                                                                                                                                                    AccessControl.rolemanager.RoleManager --+   |
                                                                                                                                                                                                                            |   |
                                                                                                                                                                                                         OFS.role.RoleManager --+
                                                                                                                                                                                                                                |
                                                                                                                                                                                       zms._accessmanager.AccessableContainer --+
                                                                                                                                                                                                                                |
                                                                                                                                                                                  zms._versionmanager.VersionManagerContainer --+
                                                                                                                                                                                                                                |
                                                                                                                                                                                                                               ZMSContainerObject

Instance Methods
`zmsobject.ZMSObject` |
manage_addZMSCustom(self, meta_id, values={}, REQUEST=None) Add a custom node of the type designated by meta_id in current context. |
`zmsobject.ZMSObject` |
manage_addZMSObject(self, meta_id, values, REQUEST) Add a node of type designated by meta_id in current context. |
moveObjsToTrashcan(self, ids, REQUEST) |
manage_eraseObjs(self, lang, ids, REQUEST, RESPONSE=None) Delete a subordinate object physically: The objects specified in 'ids' get deleted. |
manage_undoObjs(self, lang, ids, REQUEST, RESPONSE=None) Undo a subordinate object: The objects specified in 'ids' get undone (changes are rolled-back). |
manage_deleteObjs(self, lang, ids, REQUEST, RESPONSE=None) Delete a subordinate object logically: The objects specified in 'ids' get deleted (moved to trashcan). |
`str` |
getContentType(self, REQUEST) Returns MIME-type (text/html). |
manage_ajaxDragDrop(self, lang, target, REQUEST, RESPONSE) ZMSContainerObject.manage_ajaxDragDrop internal use only |
`zmsobject.ZMSObject` |
getFirstPage(self, REQUEST, incResource=False, root=None) Returns the first page of the tree from root (or document-element if root is not given). |
`zmsobject.ZMSObject` |
getPrevPage(self, REQUEST, incResource=False, root=None) Returns the previous page of this node from root (or document-element if root is not given). |
`zmsobject.ZMSObject` |
getNextPage(self, REQUEST, incResource=False, root=None) Returns the next page of this node from root (or document-element if root is not given). |
`zmsobject.ZMSObject` |
getLastPage(self, REQUEST, incResource=False, root=None) Returns the last page of the tree from root (or document-element if root is not given). |
manage_ajaxZMIActions(self, context_id, REQUEST, RESPONSE) Returns ZMI actions. |
`str` |
getNavItems(self, current, REQUEST, opt={}, depth=0) Returns html-formatted (unordered) list of navigation-items. |
getNavElements(self, REQUEST, expand_tree=1, current_child=None, subElements=[]) |
getIndexNavElements(self, REQUEST) |
`list<ZMSObject>` |
filteredTreeNodes(self, REQUEST, meta_types, order_by=None, order_dir=None, max_len=None, recursive=True) Returns a node-list that contains all visible children of this subtree in correct order. |
`ZMSObject` |
firstFilteredChildNode(self, REQUEST=None, meta_types=None) Returns the first visible child of this node. |
`list<ZMSObject>` |
filteredChildNodes(self, REQUEST=None, meta_types=None) Returns a node-list that contains all visible children of this node in correct order. |
getChildNodes(self, REQUEST=None, meta_types=None, reid=None) Returns a node-list that contains all children of this node in correct order. |
normalizeSortIds(self, id_prefix='e') Normalizes sort-ids for all children with given prefix of this node. |
`int` |
getNewSortId(self) Get new sort-id. |
manage_addZMSCustomDefault(self, lang, id_prefix, _sort_id, REQUEST, RESPONSE) Add default node. |
manage_addZMSModule(self, lang, _sort_id, custom, REQUEST, RESPONSE) Add module-node. |
Inherited from `OFS.role.RoleManager`: `manage_access`, `manage_acquiredPermissions`, `manage_addLocalRoles`, `manage_changePermissions`, `manage_defined_roles`, `manage_delLocalRoles`, `manage_editRoles`, `manage_permission`, `manage_role`, `manage_setLocalRoles` Inherited from `AccessControl.rolemanager.RoleManager`: `ac_inherited_permissions`, `access_debug_info`, `acquiredRolesAreUsedBy`, `get_local_roles`, `get_local_roles_for_userid`, `get_valid_userids`, `has_local_roles`, `manage_getUserRolesAndPermissions`, `permission_settings`, `permissionsOfRole`, `possible_permissions`, `rolesOfPermission`, `userdefined_roles`, `users_with_local_role`, `valid_roles`, `validate_roles` Inherited from `AccessControl.PermissionMapping.RoleManager`: `manage_getPermissionMapping`, `manage_setPermissionMapping`

Class Variables
| __administratorPermissions__ = `'manage_system',`
| __ac_permissions__ = `'ZMS Administrator', __administratorPermi`...``
| manage_main = `PageTemplateFile('zpt/ZMSObject/manage_main', gl`...``
| zmi_manage_main_change = `PageTemplateFile('zpt/ZMSContainerObj`...``
| zmi_manage_main_grid = `PageTemplateFile('zpt/ZMSContainerObjec`...``
| manage_container = `PageTemplateFile('zpt/ZMSContainerObject/ma`...``
| manage_properties = `PageTemplateFile('zpt/ZMSObject/manage_mai`...``
| manage_system = `PageTemplateFile('zpt/ZMSContainerObject/manag`...``
| manage_importexport = `PageTemplateFile('zpt/ZMSContainerObject`...``
| PAGES = `0`
| PAGEELEMENTS = `1`
| NOREF = `4`
| NORESOLVEREF = `5`
Inherited from `OFS.role.RoleManager`: `aclAChecked`, `aclEChecked`, `aclPChecked`, `manage_acquiredForm`, `manage_editLocalRoles`, `manage_listLocalRoles`, `manage_options`, `manage_permissionForm`, `manage_reportUserPermissions`, `manage_roleForm`, `security`, `selectedRoles`, `smallRolesWidget`, `validRoles` Inherited from `AccessControl.rolemanager.RoleManager`: `__ac_local_roles__`, `__ac_roles__`, `permissionMappingPossibleValues`

Method Details

### manage_addZMSCustom(self, meta_id, values={}, REQUEST=None) |
Add a custom node of the type designated by meta_id in current context. Parameters: `meta_id` (`str`) - the meta-id / type of the new ZMSObject `values` (`dict`) - the dictionary of initial attribut-values assigned to the new ZMSObject `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request Returns: `zmsobject.ZMSObject` the new node

### manage_addZMSObject(self, meta_id, values, REQUEST) |
Add a node of type designated by meta_id in current context. Parameters: `meta_id` (`str`) - the meta-id / type of the new ZMSObject `values` (`dict`) - the dictionary of initial attribut-values assigned to the new ZMSObject id_prefix (`str=''`) the id-prefix used to generate the new id id (`str=''`) the new id (fixed) sort_id (`str=''`) the sort-id meta_id (`str=''`) the meta-id active (`str=''`) is active attr_dc_coverage (`str=''`) the coverage `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request Returns: `zmsobject.ZMSObject` the new node

### manage_eraseObjs(self, lang, ids, REQUEST, RESPONSE=None) |
Delete a subordinate object physically: The objects specified in 'ids' get deleted. Parameters: `lang` (`str`) - the language-id. `ids` (`list`) - the list of object-ids. `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request `RESPONSE` (`ZPublisher.HTTPResponse`) - the triggering request

### manage_undoObjs(self, lang, ids, REQUEST, RESPONSE=None) |
Undo a subordinate object: The objects specified in 'ids' get undone (changes are rolled-back). Parameters: `lang` (`str`) - the language-id. `ids` (`list`) - the list of object-ids. `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request `RESPONSE` (`ZPublisher.HTTPResponse`) - the triggering request

### manage_deleteObjs(self, lang, ids, REQUEST, RESPONSE=None) |
Delete a subordinate object logically: The objects specified in 'ids' get deleted (moved to trashcan). Parameters: `lang` (`str`) - the language-id. `ids` (`list`) - the list of object-ids. `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request `RESPONSE` (`ZPublisher.HTTPResponse`) - the triggering request

### getContentType(self, REQUEST) |
Returns MIME-type (text/html). Parameters: `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request Returns: `str` always returns 'text/html'

### getFirstPage(self, REQUEST, incResource=False, root=None) |
Returns the first page of the tree from root (or document-element if root is not given). Parameters: `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request Returns: `zmsobject.ZMSObject` the first page

### getPrevPage(self, REQUEST, incResource=False, root=None) |
Returns the previous page of this node from root (or document-element if root is not given). Parameters: `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request Returns: `zmsobject.ZMSObject` the previous page

### getNextPage(self, REQUEST, incResource=False, root=None) |
Returns the next page of this node from root (or document-element if root is not given). Parameters: `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request Returns: `zmsobject.ZMSObject` the next page

### getLastPage(self, REQUEST, incResource=False, root=None) |
Returns the last page of the tree from root (or document-element if root is not given). Parameters: `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request Returns: `zmsobject.ZMSObject` the last page

### manage_ajaxZMIActions(self, context_id, REQUEST, RESPONSE) |
Returns ZMI actions. internal use only Parameters: `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request `RESPONSE` (`ZPublisher.HTTPResponse`) - the response

### getNavItems(self, current, REQUEST, opt={}, depth=0) |
Returns html-formatted (unordered) list of navigation-items. Uses the following classes current item is current-element (in-)active items is parent of current-element or current-element restricted item has restricted access Parameters: `current` (`zmsobject.ZMSObject`) - the currently displayed page `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request `opt` - the dictionary of options id (`str=''`) id of base ul-element cssclass (`str=''`) css class of base ul-element add_self (`boolean=False`) add self to list deep (`boolean=True`) process child nodes complete (`boolean=False`) process complete subtree maxdepth (`int=100`) limits node list to a given depth getrestricted (`boolean=True`) get is restricted getchildpages (`boolean=True`) get has child-pages Returns: `str` the Html

### filteredTreeNodes(self, REQUEST, meta_types, order_by=None, order_dir=None, max_len=None, recursive=True) |
Returns a node-list that contains all visible children of this subtree in correct order. If none, this is a empty node-list. Parameters: `meta_types` (`str|list`) - the meta_type(s) (single or list), may also be `ZMSContainerObject.PAGES` or `ZMSContainerObject.PAGEELEMENTS` `REQUEST` (`ZPublisher.HTTPRequest=None`) - the triggering request Returns: `list<ZMSObject>` the list of ZMSObjects

### firstFilteredChildNode(self, REQUEST=None, meta_types=None) |
Returns the first visible child of this node. Parameters: `meta_types` (`str|list`) - the meta_type(s) (single or list), may also be `ZMSContainerObject.PAGES` or `ZMSContainerObject.PAGEELEMENTS` `REQUEST` (`ZPublisher.HTTPRequest=None`) - the triggering request Returns: `ZMSObject` the first ZMSObject

### filteredChildNodes(self, REQUEST=None, meta_types=None) |
Returns a node-list that contains all visible children of this node in correct order. If none, this is a empty node-list. Parameters: `meta_types` (`str|list`) - the meta_type(s) (single or list), may also be `ZMSContainerObject.PAGES` or `ZMSContainerObject.PAGEELEMENTS` `REQUEST` (`ZPublisher.HTTPRequest=None`) - the triggering request Returns: `list<ZMSObject>` the list of ZMSObjects

### getChildNodes(self, REQUEST=None, meta_types=None, reid=None) |
Returns a node-list that contains all children of this node in correct order. If none, this is a empty node-list.

### normalizeSortIds(self, id_prefix='e') |
Normalizes sort-ids for all children with given prefix of this node. Always called on container after new node was added. E.g.: sort_ids:before=[10,15,20,30,40] => sort_ids:after=[10,20,30,40,50] Parameters: `id_prefix` (`str='e'`) - the id-prefix.

### getNewSortId(self) |
Get new sort-id. Returns: `int` the new sort-id.

### manage_addZMSCustomDefault(self, lang, id_prefix, _sort_id, REQUEST, RESPONSE) |
Add default node. internal use only Parameters: `lang` (`str`) - the language-id. `id_prefix` (`str`) - the id-prefix. `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request `RESPONSE` (`ZPublisher.HTTPResponse`) - the triggering request

### manage_addZMSModule(self, lang, _sort_id, custom, REQUEST, RESPONSE) |
Add module-node. internal use only Parameters: `lang` (`str`) - the language-id. `id_prefix` (`str`) - the id-prefix. `REQUEST` (`ZPublisher.HTTPRequest`) - the triggering request `RESPONSE` (`ZPublisher.HTTPResponse`) - the triggering request

Class Variable Details

  ### __ac_permissions__ Value:
      'ZMS Administrator', __administratorPermissions__,

  ### manage_main Value:
      PageTemplateFile('zpt/ZMSObject/manage_main', globals())

  ### zmi_manage_main_change Value:
      PageTemplateFile('zpt/ZMSContainerObject/zmi_manage_main_change', glob
      als())

  ### zmi_manage_main_grid Value:
      PageTemplateFile('zpt/ZMSContainerObject/main_grid', globals())

  ### manage_container Value:
      PageTemplateFile('zpt/ZMSContainerObject/manage_main', globals())

  ### manage_properties Value:
      PageTemplateFile('zpt/ZMSObject/manage_main', globals())

  ### manage_system Value:
      PageTemplateFile('zpt/ZMSContainerObject/manage_system', globals())

  ### manage_importexport Value:
      PageTemplateFile('zpt/ZMSContainerObject/manage_importexport', globals
      ())